@@ -20,13 +20,13 @@ import socket
 import netaddr
 from neutron.agent.linux import external_process
 from neutron.agent.linux import ip_lib
-from neutron.common import utils as n_utils
 from neutron_lib import constants
 from neutron_lib import exceptions
 from neutron_lib.utils import runtime
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import excutils
+from oslo_utils import fileutils
 
 from neutron_lbaas._i18n import _
 from neutron_lbaas.agent import agent_device_driver
@@ -51,6 +51,11 @@ OPTS = [
     cfg.StrOpt(
         'loadbalancer_state_path',
         default=STATE_PATH_DEFAULT,
+        deprecated_for_removal=True,
+        deprecated_since='Queens',
+        deprecated_reason='The neutron-lbaas project is now deprecated. '
+                          'See: https://wiki.openstack.org/wiki/Neutron/LBaaS/'
+                          'Deprecation',
         help=_('Location to store config and state files'),
         deprecated_opts=[cfg.DeprecatedOpt('loadbalancer_state_path',
                                            group='DEFAULT')],
@@ -59,11 +64,21 @@ OPTS = [
         'user_group',
         default=USER_GROUP_DEFAULT,
         help=_('The user group'),
+        deprecated_for_removal=True,
+        deprecated_since='Queens',
+        deprecated_reason='The neutron-lbaas project is now deprecated. '
+                          'See: https://wiki.openstack.org/wiki/Neutron/LBaaS/'
+                          'Deprecation',
         deprecated_opts=[cfg.DeprecatedOpt('user_group', group='DEFAULT')],
     ),
     cfg.IntOpt(
         'send_gratuitous_arp',
         default=3,
+        deprecated_for_removal=True,
+        deprecated_since='Queens',
+        deprecated_reason='The neutron-lbaas project is now deprecated. '
+                          'See: https://wiki.openstack.org/wiki/Neutron/LBaaS/'
+                          'Deprecation',
         help=_('When delete and re-add the same vip, send this many '
                'gratuitous ARPs to flush the ARP cache in the Router. '
                'Set it below or equal to 0 to disable this feature.'),
@@ -298,9 +313,9 @@ class HaproxyNSDriver(agent_device_driver.AgentDeviceDriver):
         for stats in parsed_stats:
             if stats.get('type') == STATS_TYPE_SERVER_RESPONSE:
                 res[stats['svname']] = {
-                    lb_const.STATS_STATUS: (constants.INACTIVE
+                    lb_const.OPERATING_STATUS: (lb_const.OFFLINE
                                             if stats['status'] == 'DOWN'
-                                            else constants.ACTIVE),
+                                            else lb_const.ONLINE),
                     lb_const.STATS_HEALTH: stats['check_status'],
                     lb_const.STATS_FAILED_CHECKS: stats['chkfail']
                 }
@@ -312,7 +327,7 @@ class HaproxyNSDriver(agent_device_driver.AgentDeviceDriver):
         confs_dir = os.path.abspath(os.path.normpath(self.state_path))
         conf_dir = os.path.join(confs_dir, loadbalancer_id)
         if ensure_state_dir:
-            n_utils.ensure_dir(conf_dir)
+            fileutils.ensure_tree(conf_dir, 0o755)
         return os.path.join(conf_dir, kind)
 
     def _plug(self, namespace, port, vip_address, reuse_existing=True):
@@ -458,7 +473,20 @@ class LoadBalancerManager(agent_device_driver.BaseLoadBalancerManager):
         self.refresh(loadbalancer)
 
     def get_stats(self, loadbalancer_id):
-        return self.driver.get_stats(loadbalancer_id)
+        stats = self.driver.get_stats(loadbalancer_id)
+
+        # NOTE(cgoncalves): haproxy stats include member status which maps to
+        # MemberV2.operating_status. Take the opportunty to update member
+        # operating status.
+        members = stats.get('members')
+        if members:
+            for member_id, value in members.items():
+                if lb_const.OPERATING_STATUS in value:
+                    self.driver.plugin_rpc.update_status(
+                        'member', member_id,
+                        operating_status=value[lb_const.OPERATING_STATUS])
+
+        return stats
 
     def update(self, old_loadbalancer, loadbalancer):
         self.refresh(loadbalancer)
