@@ -59,6 +59,14 @@ class LoggingNoopCommonManager(object):
 class LoggingNoopLoadBalancerManager(LoggingNoopCommonManager,
                                      driver_base.BaseLoadBalancerManager):
 
+    @property
+    def allows_create_graph(self):
+        return True
+
+    @property
+    def allows_healthmonitor_thresholds(self):
+        return True
+
     @property
     def allocates_vip(self):
         LOG.debug('allocates_vip queried')
