@@ -12,14 +12,14 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import base64
-import httplib
+import ssl
 
 from oslo_log import helpers as log_helpers
 from oslo_log import log as logging
+from oslo_serialization import base64
 from oslo_serialization import jsonutils
+from six.moves import http_client
 
-from neutron_lbaas._i18n import _LE, _LW
 from neutron_lbaas.drivers.radware import exceptions as r_exc
 
 LOG = logging.getLogger(__name__)
@@ -40,16 +40,18 @@ class vDirectRESTClient(object):
                  password=None,
                  port=2189,
                  ssl=True,
+                 ssl_verify_context=True,
                  timeout=5000,
                  base_uri=''):
         self.server = server
         self.secondary_server = secondary_server
         self.port = port
         self.ssl = ssl
+        self.ssl_verify_context = ssl_verify_context
         self.base_uri = base_uri
         self.timeout = timeout
         if user and password:
-            self.auth = base64.encodestring('%s:%s' % (user, password))
+            self.auth = base64.encode_as_text('%s:%s' % (user, password))
             self.auth = self.auth.replace('\n', '')
         else:
             raise r_exc.AuthenticationMissing()
@@ -57,17 +59,19 @@ class vDirectRESTClient(object):
         debug_params = {'server': self.server,
                         'sec_server': self.secondary_server,
                         'port': self.port,
-                        'ssl': self.ssl}
+                        'ssl': self.ssl,
+                        'ssl_verify_context': self.ssl_verify_context}
         LOG.debug('vDirectRESTClient:init server=%(server)s, '
                   'secondary server=%(sec_server)s, '
                   'port=%(port)d, '
-                  'ssl=%(ssl)r', debug_params)
+                  'ssl=%(ssl)r, '
+                  'ssl_verify_context=%(ssl_verify_context)r' %
+                  debug_params)
 
     def _flip_servers(self):
-        LOG.warning(_LW('Fliping servers. Current is: %(server)s, '
-                 'switching to %(secondary)s'),
-                 {'server': self.server,
-                 'secondary': self.secondary_server})
+        LOG.warning('Flipping servers. Current is: %(server)s, switching to '
+                    '%(secondary)s', {'server': self.server,
+                                      'secondary': self.secondary_server})
         self.server, self.secondary_server = self.secondary_server, self.server
 
     def _recover(self, action, resource, data, headers, binary=False):
@@ -77,19 +81,19 @@ class vDirectRESTClient(object):
                               headers, binary)
             return resp
         else:
-            LOG.error(_LE('REST client is not able to recover '
-                          'since only one vDirect server is '
-                          'configured.'))
+            LOG.error('REST client is not able to recover '
+                      'since only one vDirect server is '
+                      'configured.')
             return -1, None, None, None
 
     def call(self, action, resource, data, headers, binary=False):
         resp = self._call(action, resource, data, headers, binary)
         if resp[RESP_STATUS] == -1:
-            LOG.warning(_LW('vDirect server is not responding (%s).'),
+            LOG.warning('vDirect server is not responding (%s).',
                         self.server)
             return self._recover(action, resource, data, headers, binary)
         elif resp[RESP_STATUS] in (301, 307):
-            LOG.warning(_LW('vDirect server is not active (%s).'),
+            LOG.warning('vDirect server is not active (%s).',
                         self.server)
             return self._recover(action, resource, data, headers, binary)
         else:
@@ -114,18 +118,35 @@ class vDirectRESTClient(object):
             headers['Authorization'] = 'Basic %s' % self.auth
         conn = None
         if self.ssl:
-            conn = httplib.HTTPSConnection(
+            if not self.ssl_verify_context:
+                # HTTPS certificate verification was cancelled in
+                # configuration. If python version has context attribute,
+                # switch the default context to unverified
+                try:
+                    _create_unverified_https_context =\
+                        ssl._create_unverified_context
+                except AttributeError:
+                    # Legacy Python that doesn't verify HTTPS
+                    # certificates by default
+                    pass
+                else:
+                    # Handle target environment that doesn't
+                    # support HTTPS verification
+                    ssl._create_default_https_context =\
+                        _create_unverified_https_context
+
+            conn = http_client.HTTPSConnection(
                 self.server, self.port, timeout=self.timeout)
             if conn is None:
-                LOG.error(_LE('vdirectRESTClient: Could not establish HTTPS '
-                          'connection'))
+                LOG.error('vdirectRESTClient: Could not establish HTTPS '
+                          'connection')
                 return 0, None, None, None
         else:
-            conn = httplib.HTTPConnection(
+            conn = http_client.HTTPConnection(
                 self.server, self.port, timeout=self.timeout)
             if conn is None:
-                LOG.error(_LE('vdirectRESTClient: Could not establish HTTP '
-                          'connection'))
+                LOG.error('vdirectRESTClient: Could not establish HTTP '
+                          'connection')
                 return 0, None, None, None
 
         try:
@@ -141,7 +162,7 @@ class vDirectRESTClient(object):
             ret = (response.status, response.reason, respstr, respdata)
         except Exception as e:
             log_dict = {'action': action, 'e': e}
-            LOG.error(_LE('vdirectRESTClient: %(action)s failure, %(e)r'),
+            LOG.error('vdirectRESTClient: %(action)s failure, %(e)r',
                       log_dict)
             ret = -1, None, None, None
         conn.close()
