@@ -19,12 +19,12 @@ from neutron_lib.api import extensions as api_extensions
 from neutron_lib import constants as n_constants
 from neutron_lib.db import constants as db_const
 from neutron_lib import exceptions as nexception
+from neutron_lib.plugins import constants
 from neutron_lib.plugins import directory
 
 from neutron.api import extensions
 from neutron.api.v2 import base
 from neutron.api.v2 import resource_helper
-from neutron.plugins.common import constants
 
 from neutron_lbaas._i18n import _
 from neutron_lbaas.extensions import loadbalancerv2
@@ -183,10 +183,6 @@ class L7(api_extensions.ExtensionDescriptor):
     def get_description(cls):
         return "Adding L7 policies and rules support for LBaaSv2"
 
-    @classmethod
-    def get_namespace(cls):
-        return "http://wiki.openstack.org/neutron/LBaaS/API_2.0"
-
     @classmethod
     def get_updated(cls):
         return "2016-01-24T10:00:00-00:00"
@@ -194,6 +190,7 @@ class L7(api_extensions.ExtensionDescriptor):
     def get_required_extensions(self):
         return ["lbaasv2"]
 
+    @classmethod
     def get_resources(cls):
         l7_plurals = {'l7policies': 'l7policy', 'rules': 'rule'}
 
