@@ -146,6 +146,17 @@ def _validate_connection_limit(data, min_value=lb_const.MIN_CONNECT_VALUE):
 
 validators.validators['type:connection_limit'] = _validate_connection_limit
 
+
+def _validate_db_limit(data, max_value=db_const.DB_INTEGER_MAX_VALUE):
+    if int(data) > max_value:
+        msg = (_("'%(data)s' is not a valid value, "
+                 "because it is more than %(max_value)s") %
+               {'data': data, 'max_value': max_value})
+        LOG.debug(msg)
+        return msg
+
+validators.validators['type:db_out_of_bounds'] = _validate_db_limit
+
 RESOURCE_ATTRIBUTE_MAP = {
     'loadbalancers': {
         'id': {'allow_post': False, 'allow_put': False,
@@ -318,7 +329,10 @@ RESOURCE_ATTRIBUTE_MAP = {
                      'type:values': lb_const.SUPPORTED_HEALTH_MONITOR_TYPES},
                  'is_visible': True},
         'delay': {'allow_post': True, 'allow_put': True,
-                  'validate': {'type:non_negative': None},
+                  'validate': {
+                      'type:db_out_of_bounds':
+                          db_const.DB_INTEGER_MAX_VALUE,
+                      'type:non_negative': None},
                   'convert_to': converters.convert_to_int,
                   'is_visible': True},
         'timeout': {'allow_post': True, 'allow_put': True,
@@ -404,22 +418,47 @@ SUB_RESOURCE_ATTRIBUTE_MAP = {
 lbaasv2_quota_opts = [
     cfg.IntOpt('quota_loadbalancer',
                default=10,
+               deprecated_for_removal=True,
+               deprecated_since='Queens',
+               deprecated_reason='The neutron-lbaas project is now '
+                                 'deprecated. See: https://wiki.openstack.org/'
+                                 'wiki/Neutron/LBaaS/Deprecation',
                help=_('Number of LoadBalancers allowed per tenant. '
                       'A negative value means unlimited.')),
     cfg.IntOpt('quota_listener',
                default=-1,
+               deprecated_for_removal=True,
+               deprecated_since='Queens',
+               deprecated_reason='The neutron-lbaas project is now '
+                                 'deprecated. See: https://wiki.openstack.org/'
+                                 'wiki/Neutron/LBaaS/Deprecation',
                help=_('Number of Loadbalancer Listeners allowed per tenant. '
                       'A negative value means unlimited.')),
     cfg.IntOpt('quota_pool',
                default=10,
+               deprecated_for_removal=True,
+               deprecated_since='Queens',
+               deprecated_reason='The neutron-lbaas project is now '
+                                 'deprecated. See: https://wiki.openstack.org/'
+                                 'wiki/Neutron/LBaaS/Deprecation',
                help=_('Number of pools allowed per tenant. '
                       'A negative value means unlimited.')),
     cfg.IntOpt('quota_member',
                default=-1,
+               deprecated_for_removal=True,
+               deprecated_since='Queens',
+               deprecated_reason='The neutron-lbaas project is now '
+                                 'deprecated. See: https://wiki.openstack.org/'
+                                 'wiki/Neutron/LBaaS/Deprecation',
                help=_('Number of pool members allowed per tenant. '
                       'A negative value means unlimited.')),
     cfg.IntOpt('quota_healthmonitor',
                default=-1,
+               deprecated_for_removal=True,
+               deprecated_since='Queens',
+               deprecated_reason='The neutron-lbaas project is now '
+                                 'deprecated. See: https://wiki.openstack.org/'
+                                 'wiki/Neutron/LBaaS/Deprecation',
                help=_('Number of health monitors allowed per tenant. '
                       'A negative value means unlimited.'))
 ]
@@ -438,11 +477,11 @@ class Loadbalancerv2(api_extensions.ExtensionDescriptor):
 
     @classmethod
     def get_description(cls):
-        return "Extension for LoadBalancing service v2"
+        return "Extension for LoadBalancing service v2 (deprecated)"
 
     @classmethod
     def get_updated(cls):
-        return "2014-06-18T10:00:00-00:00"
+        return "2018-01-31T10:00:00-00:00"
 
     @classmethod
     def get_resources(cls):
@@ -509,7 +548,7 @@ class LoadBalancerPluginBaseV2(service_base.ServicePluginBase):
         return constants.LOADBALANCERV2
 
     def get_plugin_description(self):
-        return 'LoadBalancer service plugin v2'
+        return 'LoadBalancer service plugin v2 (deprecated)'
 
     @abc.abstractmethod
     def get_loadbalancers(self, context, filters=None, fields=None):
