@@ -15,14 +15,15 @@
 
 import copy
 
+from neutron_lib.api import attributes
 from neutron_lib import context as ncontext
+from neutron_lib import exceptions as lib_exc
+from neutron_lib.exceptions import flavors as flav_exc
 from neutron_lib.plugins import directory
 
-from neutron.api.v2 import attributes as attrs
 from neutron.api.v2 import base as napi_base
 from neutron.db import agentschedulers_db
 from neutron.db import servicetype_db as st_db
-from neutron.extensions import flavors
 from neutron import service
 from neutron.services.flavors import flavors_plugin
 from neutron.services import provider_configuration as pconf
@@ -79,6 +80,9 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
 
     def __init__(self):
         """Initialization for the loadbalancer service plugin."""
+        LOG.warning('neutron-lbaas is now deprecated. See: '
+                    'https://wiki.openstack.org/wiki/Neutron/LBaaS/'
+                    'Deprecation')
         self.db = ldbv2.LoadBalancerPluginDbv2()
         self.service_type_manager = st_db.ServiceTypeManager.get_instance()
         add_provider_configuration(
@@ -120,11 +124,11 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
         from configuration, neutron service is stopped. Admin must delete
         resources prior to removing providers from configuration.
         """
-        used_provider_names = (
-            self.db.get_provider_names_used_in_loadbalancers(context))
+        loadbalancers = self.db.get_loadbalancers(context)
         lost_providers = set(
-            [name for name in used_provider_names
-                if name not in provider_names])
+            [lb.provider.provider_name
+             for lb in loadbalancers
+             if lb.provider.provider_name not in provider_names])
         # resources are left without provider - stop the service
         if lost_providers:
             msg = ("Delete associated load balancers before "
@@ -242,11 +246,11 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
             loadbalancer['flavor_id'])
 
         if fl_db['service_type'] != constants.LOADBALANCERV2:
-            raise flavors.InvalidFlavorServiceType(
+            raise lib_exc.InvalidServiceType(
                 service_type=fl_db['service_type'])
 
         if not fl_db['enabled']:
-            raise flavors.FlavorDisabled()
+            raise flav_exc.FlavorDisabled()
 
         providers = flavors_plugin.FlavorsPlugin.get_flavor_next_provider(
             plugin,
@@ -262,7 +266,7 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
     def _get_tweaked_resource_attribute_map(self):
         memo = {id(n_constants.ATTR_NOT_SPECIFIED):
                 n_constants.ATTR_NOT_SPECIFIED}
-        ram = copy.deepcopy(attrs.RESOURCE_ATTRIBUTE_MAP, memo=memo)
+        ram = copy.deepcopy(attributes.RESOURCES, memo=memo)
         del ram['listeners']['loadbalancer_id']
         del ram['pools']['listener_id']
         del ram['healthmonitors']['pool_id']
