@@ -27,11 +27,14 @@ enable_plugin barbican https://git.openstack.org/openstack/barbican
 # Sort out our gate args
 . $(dirname "$0")/decode_args.sh
 
-if egrep --quiet '(vmx|svm)' /proc/cpuinfo; then
+# Note: The check for OVH instances is temporary until they resolve the
+# KVM failures as logged here:
+# https://bugzilla.kernel.org/show_bug.cgi?id=192521
+# However, this may be resolved at OVH before the kernel bug is resolved.
+if $(egrep --quiet '(vmx|svm)' /proc/cpuinfo) && [[ ! $(hostname) =~ "ovh" ]]; then
     export DEVSTACK_GATE_LIBVIRT_TYPE=kvm
 fi
 
-
 function _setup_octavia {
     export DEVSTACK_LOCAL_CONFIG+="
         enable_plugin octavia https://git.openstack.org/openstack/octavia
