@@ -14,10 +14,10 @@
 #    under the License.
 
 import netaddr
+from tempest.common import utils
 from tempest.lib.common.utils import data_utils
 from tempest.lib import decorators
 from tempest.lib import exceptions as ex
-from tempest import test
 
 from neutron_lbaas.tests.tempest.v2.api import base
 
@@ -38,7 +38,7 @@ class LoadBalancersTestJSON(base.BaseTestCase):
     @classmethod
     def resource_setup(cls):
         super(LoadBalancersTestJSON, cls).resource_setup()
-        if not test.is_extension_enabled('lbaasv2', 'network'):
+        if not utils.is_extension_enabled('lbaasv2', 'network'):
             msg = "lbaas extension not enabled."
             raise cls.skipException(msg)
         network_name = data_utils.rand_name('network')
