@@ -1,4 +1,4 @@
-# Copyright 2015 Rackspace US Inc.  All rights reserved.
+# Copyright 2015, 2016 Rackspace US Inc.  All rights reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
@@ -12,14 +12,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import urllib
-
 from oslo_serialization import jsonutils
-
-from neutron_lbaas.tests.tempest.lib.common import service_client
+from six.moves.urllib import parse
+from tempest.lib.common import rest_client
 
 
-class ListenersClientJSON(service_client.ServiceClient):
+class ListenersClientJSON(rest_client.RestClient):
     """
     Tests Listeners API
     """
@@ -28,21 +26,21 @@ class ListenersClientJSON(service_client.ServiceClient):
         """List all listeners."""
         url = 'v2.0/lbaas/listeners'
         if params:
-            url = '{0}?{1}'.format(url, urllib.urlencode(params))
+            url = '{0}?{1}'.format(url, parse.urlencode(params))
         resp, body = self.get(url)
         body = jsonutils.loads(body)
         self.expected_success(200, resp.status)
-        return service_client.ResponseBodyList(resp, body['listeners'])
+        return rest_client.ResponseBodyList(resp, body['listeners'])
 
     def get_listener(self, listener_id, params=None):
         """Get listener details."""
         url = 'v2.0/lbaas/listeners/{0}'.format(listener_id)
         if params:
-            url = '{0}?{1}'.format(url, urllib.urlencode(params))
+            url = '{0}?{1}'.format(url, parse.urlencode(params))
         resp, body = self.get(url)
         body = jsonutils.loads(body)
         self.expected_success(200, resp.status)
-        return service_client.ResponseBody(resp, body['listener'])
+        return rest_client.ResponseBody(resp, body['listener'])
 
     def create_listener(self, **kwargs):
         """Create a listener build."""
@@ -50,7 +48,7 @@ class ListenersClientJSON(service_client.ServiceClient):
         resp, body = self.post('v2.0/lbaas/listeners', post_body)
         body = jsonutils.loads(body)
         self.expected_success(201, resp.status)
-        return service_client.ResponseBody(resp, body['listener'])
+        return rest_client.ResponseBody(resp, body['listener'])
 
     def update_listener(self, listener_id, **kwargs):
         """Update an listener build."""
@@ -59,11 +57,11 @@ class ListenersClientJSON(service_client.ServiceClient):
                               .format(listener_id), put_body)
         body = jsonutils.loads(body)
         self.expected_success(200, resp.status)
-        return service_client.ResponseBody(resp, body['listener'])
+        return rest_client.ResponseBody(resp, body['listener'])
 
     def delete_listener(self, listener_id):
         """Delete an existing listener build."""
         resp, body = self.delete("v2.0/lbaas/listeners/{0}"
                                  .format(listener_id))
         self.expected_success(204, resp.status)
-        return service_client.ResponseBody(resp, body)
+        return rest_client.ResponseBody(resp, body)
