@@ -29,7 +29,7 @@ class TestHaproxyCfg(base.BaseTestCase):
     def test_save_config(self):
         with mock.patch('neutron_lbaas.drivers.haproxy.'
                         'jinja_cfg.render_loadbalancer_obj') as r_t, \
-                mock.patch('neutron.common.utils.replace_file') as replace:
+                mock.patch('neutron_lib.utils.file.replace_file') as replace:
             r_t.return_value = 'fake_rendered_template'
             lb = mock.Mock()
             jinja_cfg.save_config('test_conf_path', lb, 'test_sock_path',
@@ -75,7 +75,7 @@ class TestHaproxyCfg(base.BaseTestCase):
               % sample_configs.PIPED_CODES)
         with mock.patch('os.makedirs'):
             with mock.patch('os.listdir'):
-                with mock.patch.object(jinja_cfg, 'n_utils'):
+                with mock.patch.object(jinja_cfg, 'file_utils'):
                     with mock.patch.object(
                             jinja_cfg, '_process_tls_certificates') as crt:
                         crt.return_value = {
@@ -118,9 +118,9 @@ class TestHaproxyCfg(base.BaseTestCase):
               "weight 13 check inter 30s fall 3 cookie sample_member_id_2\n\n"
               % sample_configs.PIPED_CODES)
         with mock.patch('os.makedirs'):
-            with mock.patch('neutron.common.utils.replace_file'):
+            with mock.patch('neutron_lib.utils.file.replace_file'):
                 with mock.patch('os.listdir'):
-                    with mock.patch.object(jinja_cfg, 'n_utils'):
+                    with mock.patch.object(jinja_cfg, 'file_utils'):
                         with mock.patch.object(
                                 jinja_cfg, '_process_tls_certificates') as crt:
                             crt.return_value = {
@@ -276,7 +276,7 @@ class TestHaproxyCfg(base.BaseTestCase):
 
     def test_render_template_appsession_persistence(self):
         with mock.patch('os.makedirs') as md:
-            with mock.patch.object(jinja_cfg, 'n_utils'):
+            with mock.patch.object(jinja_cfg, 'file_utils'):
                 md.return_value = '/data/dirs/'
                 be = ("backend sample_pool_id_1\n"
                       "    mode http\n"
@@ -314,7 +314,7 @@ class TestHaproxyCfg(base.BaseTestCase):
     def test_store_listener_crt(self):
         l = sample_configs.sample_listener_tuple(tls=True, sni=True)
         with mock.patch('os.makedirs'):
-            with mock.patch('neutron.common.utils.replace_file'):
+            with mock.patch('neutron_lib.utils.file.replace_file'):
                     ret = jinja_cfg._store_listener_crt(
                         '/v2/loadbalancers', l, l.default_tls_container)
                     self.assertEqual(
