@@ -22,9 +22,7 @@ from neutron_lib import context
 from neutron_lib.plugins import directory
 
 from neutron.api import extensions
-from neutron.api.v2 import attributes
 from neutron.db import agents_db
-from neutron.extensions import agent
 from neutron.tests.common import helpers
 from neutron.tests.unit.api import test_extensions
 from neutron.tests.unit.db import test_agentschedulers_db
@@ -39,6 +37,7 @@ from neutron_lbaas.extensions import lbaas_agentschedulerv2
 from neutron_lbaas.services.loadbalancer import constants as lb_const
 from neutron_lbaas.tests import base
 from neutron_lbaas.tests.unit.db.loadbalancer import test_db_loadbalancerv2
+from neutron_lbaas.tests.unit.db.loadbalancer import util
 
 LBAAS_HOSTA = 'hosta'
 extensions_path = ':'.join(neutron.tests.unit.extensions.__path__)
@@ -66,7 +65,7 @@ class AgentSchedulerTestMixIn(test_agentschedulers_db.AgentSchedulerTestMixIn):
 
 class LBaaSAgentSchedulerTestCase(test_agent.AgentDBTestMixIn,
                                   AgentSchedulerTestMixIn,
-                                  test_db_loadbalancerv2.LbaasTestMixin,
+                                  util.LbaasTestMixin,
                                   base.NeutronDbPluginV2TestCase):
     fmt = 'json'
     plugin_str = 'neutron.plugins.ml2.plugin.Ml2Plugin'
@@ -95,10 +94,6 @@ class LBaaSAgentSchedulerTestCase(test_agent.AgentDBTestMixIn,
         return res
 
     def setUp(self):
-        # Save the global RESOURCE_ATTRIBUTE_MAP
-        self.saved_attr_map = {}
-        for res, attrs in attributes.RESOURCE_ATTRIBUTE_MAP.items():
-            self.saved_attr_map[res] = attrs.copy()
         service_plugins = {
             'lb_plugin_name': test_db_loadbalancerv2.DB_LB_PLUGIN_CLASS}
 
@@ -112,19 +107,8 @@ class LBaaSAgentSchedulerTestCase(test_agent.AgentDBTestMixIn,
         ext_mgr = extensions.PluginAwareExtensionManager.get_instance()
         self.ext_api = test_extensions.setup_extensions_middleware(ext_mgr)
         self.adminContext = context.get_admin_context()
-        # Add the resources to the global attribute map
-        # This is done here as the setup process won't
-        # initialize the main API router which extends
-        # the global attribute map
-        attributes.RESOURCE_ATTRIBUTE_MAP.update(
-            agent.RESOURCE_ATTRIBUTE_MAP)
         self.lbaas_plugin = directory.get_plugin(plugin_const.LOADBALANCERV2)
         self.core_plugin = directory.get_plugin()
-        self.addCleanup(self.restore_attribute_map)
-
-    def restore_attribute_map(self):
-        # Restore the original RESOURCE_ATTRIBUTE_MAP
-        attributes.RESOURCE_ATTRIBUTE_MAP = self.saved_attr_map
 
     def test_report_states(self):
         self._register_agent_states(lbaas_agents=True)
